@@ -25,6 +25,8 @@ type GlobalOptions struct {
 	StateValuesFile []string
 	// SkipDeps is true if the running "helm repo update" and "helm dependency build" should be skipped
 	SkipDeps bool
+	// StripArgsValuesOnExitError is true if the ARGS output on exit error should be suppressed
+	StripArgsValuesOnExitError bool
 	// DisableForceUpdate is true if force updating repos is not desirable when executing "helm repo add"
 	DisableForceUpdate bool
 	// Quiet is true if the output should be quiet.
@@ -70,19 +72,19 @@ func (g *GlobalOptions) SetLogger(logger *zap.SugaredLogger) {
 // GlobalImpl is the global configuration for the Helmfile CLI.
 type GlobalImpl struct {
 	*GlobalOptions
-	set map[string]interface{}
+	set map[string]any
 }
 
 // NewGlobalImpl creates a new GlobalImpl.
 func NewGlobalImpl(opts *GlobalOptions) *GlobalImpl {
 	return &GlobalImpl{
 		GlobalOptions: opts,
-		set:           make(map[string]interface{}),
+		set:           make(map[string]any),
 	}
 }
 
 // Setset sets the set
-func (g *GlobalImpl) SetSet(set map[string]interface{}) {
+func (g *GlobalImpl) SetSet(set map[string]any) {
 	g.set = set
 }
 
@@ -117,7 +119,7 @@ func (g *GlobalImpl) Selectors() []string {
 }
 
 // StateValuesSet returns the set
-func (g *GlobalImpl) StateValuesSet() map[string]interface{} {
+func (g *GlobalImpl) StateValuesSet() map[string]any {
 	return g.set
 }
 
@@ -141,6 +143,11 @@ func (g *GlobalImpl) SkipDeps() bool {
 	return g.GlobalOptions.SkipDeps
 }
 
+// StripArgsValuesOnExitError return if the ARGS output on exit error should be suppressed
+func (g *GlobalImpl) StripArgsValuesOnExitError() bool {
+	return g.GlobalOptions.StripArgsValuesOnExitError
+}
+
 // DisableForceUpdate return when to disable forcing updates to repos upon adding
 func (g *GlobalImpl) DisableForceUpdate() bool {
 	return g.GlobalOptions.DisableForceUpdate
