@@ -248,7 +248,7 @@ func (c *StateCreator) loadEnvValues(st *HelmState, name string, failOnMissingEn
 				return nil, err
 			}
 		}
-	} else if ctxEnv == nil && name != DefaultEnv && failOnMissingEnv {
+	} else if ctxEnv == nil && overrode == nil && name != DefaultEnv && failOnMissingEnv {
 		return nil, &UndefinedEnvError{Env: name}
 	}
 
